==> ui-framework-4.5.4-sources.jar: io/intino/alexandria/ui/displays/items/Sorting2Mold.java <==
package io.intino.alexandria.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class Sorting2Mold extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, io.intino.alexandria.ui.documentation.Person, UiFrameworkBox> {
	public FirstName2 firstName2;
	public Sor_46_7_02043339169 sor_46_7_02043339169;
	public Sorting2Mold.Sor_46_7_02043339169. Gender2 gender2;
	public Sorting2Mold.Sor_46_7_02043339169. Age2 age2;

    public Sorting2Mold(UiFrameworkBox box) {
        super(box);
        id("a1504921654");
    }

    @Override
	public void init() {
		super.init();
		if (firstName2 == null) firstName2 = register(new FirstName2(box()).<FirstName2>id("a1958293984").owner(Sorting2Mold.this));
		if (sor_46_7_02043339169 == null) sor_46_7_02043339169 = register(new Sor_46_7_02043339169(box()).<Sor_46_7_02043339169>id("a1008327381").owner(Sorting2Mold.this));
		if (sor_46_7_02043339169 != null) gender2 = sor_46_7_02043339169.gender2;
		if (sor_46_7_02043339169 != null) age2 = sor_46_7_02043339169.age2;
	}

	public class FirstName2 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

		public FirstName2(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class Sor_46_7_02043339169 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UiFrameworkBox>  {
		public Sorting2Mold.Sor_46_7_02043339169. Gender2 gender2;
		public Sorting2Mold.Sor_46_7_02043339169. Age2 age2;

		public Sor_46_7_02043339169(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (gender2 == null) gender2 = register(new Gender2(box()).<Gender2>id("a_498103545").owner(Sorting2Mold.this));
			if (age2 == null) age2 = register(new Age2(box()).<Age2>id("a251094365").owner(Sorting2Mold.this));
		}

		public class Gender2 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Gender2(UiFrameworkBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Age2 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Age2(UiFrameworkBox box) {
				super(box);
				label("age");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> ui-framework-4.14.8-sources.jar: io/intino/alexandria/ui/displays/items/Sorting2Mold.java <==
package io.intino.alexandria.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class Sorting2Mold extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, io.intino.alexandria.ui.documentation.Person, UiFrameworkBox> {
	public FirstName2 firstName2;
	public _46_7_02043339169 _46_7_02043339169;
	public Sorting2Mold._46_7_02043339169. Gender2 gender2;
	public Sorting2Mold._46_7_02043339169. Age2 age2;

    public Sorting2Mold(UiFrameworkBox box) {
        super(box);
        id("a1504921654");
    }

    @Override
	public void init() {
		super.init();
		if (firstName2 == null) firstName2 = register(new FirstName2(box()).<FirstName2>id("a1958293984").owner(Sorting2Mold.this));
		if (_46_7_02043339169 == null) _46_7_02043339169 = register(new _46_7_02043339169(box()).<_46_7_02043339169>id("a_1116595847").owner(Sorting2Mold.this));
		if (_46_7_02043339169 != null) gender2 = _46_7_02043339169.gender2;
		if (_46_7_02043339169 != null) age2 = _46_7_02043339169.age2;
	}

	public class FirstName2 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

		public FirstName2(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class _46_7_02043339169 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UiFrameworkBox>  {
		public Sorting2Mold._46_7_02043339169. Gender2 gender2;
		public Sorting2Mold._46_7_02043339169. Age2 age2;

		public _46_7_02043339169(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (gender2 == null) gender2 = register(new Gender2(box()).<Gender2>id("a_498103545").owner(Sorting2Mold.this));
			if (age2 == null) age2 = register(new Age2(box()).<Age2>id("a251094365").owner(Sorting2Mold.this));
		}

		public class Gender2 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Gender2(UiFrameworkBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Age2 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Age2(UiFrameworkBox box) {
				super(box);
				label("age");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}
